summaryrefslogtreecommitdiff
path: root/src/encoder.hpp
diff options
context:
space:
mode:
authorMartin Sustrik <sustrik@250bpm.com>2012-02-16 10:01:47 +0900
committerMartin Sustrik <sustrik@250bpm.com>2012-02-16 10:01:47 +0900
commit4a7aad06d95701cf232198093ce396dcdbb53e5b (patch)
tree8ced8929e603a179d9434099244dfd782e705d5e /src/encoder.hpp
parent1fc63e4dbcf1438eb571d720f57be68852f820f7 (diff)
ZeroMQ renamed to Crossroads
Signed-off-by: Martin Sustrik <sustrik@250bpm.com>
Diffstat (limited to 'src/encoder.hpp')
-rw-r--r--src/encoder.hpp21
1 files changed, 11 insertions, 10 deletions
diff --git a/src/encoder.hpp b/src/encoder.hpp
index f521b6b..93efbb8 100644
--- a/src/encoder.hpp
+++ b/src/encoder.hpp
@@ -1,16 +1,16 @@
/*
- Copyright (c) 2009-2011 250bpm s.r.o.
+ Copyright (c) 2009-2012 250bpm s.r.o.
Copyright (c) 2007-2009 iMatix Corporation
Copyright (c) 2007-2011 Other contributors as noted in the AUTHORS file
- This file is part of 0MQ.
+ This file is part of Crossroads project.
- 0MQ is free software; you can redistribute it and/or modify it under
+ Crossroads is free software; you can redistribute it and/or modify it under
the terms of the GNU Lesser General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.
- 0MQ is distributed in the hope that it will be useful,
+ Crossroads is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.
@@ -19,8 +19,8 @@
along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef __ZMQ_ENCODER_HPP_INCLUDED__
-#define __ZMQ_ENCODER_HPP_INCLUDED__
+#ifndef __XS_ENCODER_HPP_INCLUDED__
+#define __XS_ENCODER_HPP_INCLUDED__
#include <stddef.h>
#include <string.h>
@@ -30,7 +30,7 @@
#include "err.hpp"
#include "msg.hpp"
-namespace zmq
+namespace xs
{
class session_base_t;
@@ -166,7 +166,8 @@ namespace zmq
void operator = (const encoder_base_t&);
};
// Encoder for 0MQ framing protocol. Converts messages into data batches.
class encoder_t : public encoder_base_t <encoder_t>
{
@@ -175,14 +176,14 @@ namespace zmq
encoder_t (size_t bufsize_);
~encoder_t ();
- void set_session (zmq::session_base_t *session_);
+ void set_session (xs::session_base_t *session_);
private:
bool size_ready ();
bool message_ready ();
- zmq::session_base_t *session;
+ xs::session_base_t *session;
msg_t in_progress;
unsigned char tmpbuf [10];
@@ -166,7 +166,8 @@ namespace zmq
void operator = (const encoder_base_t&);
};
- // Encoder for 0MQ framing protocol. Converts messages into data batches.
+ // Encoder for Crossroads framing protocol.
+ // Converts messages into data batches.
class encoder_t : public encoder_base_t <encoder_t>
{